# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.tools_controller_api import ToolsControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestToolsControllerApi(unittest.TestCase):
    """ToolsControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.tools_controller_api.ToolsControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_analyze_dmarc_report(self):
        """Test case for analyze_dmarc_report

        Parse and summarize a DMARC aggregate XML report  # noqa: E501
        """
        pass

    def test_analyze_email_headers(self):
        """Test case for analyze_email_headers

        Analyze email headers for auth results and delivery path  # noqa: E501
        """
        pass

    def test_check_campaign_probe(self):
        """Test case for check_campaign_probe

        Run a one-shot free campaign probe preflight check  # noqa: E501
        """
        pass

    def test_check_dns_propagation(self):
        """Test case for check_dns_propagation

        Check DNS propagation for a host and record type across configured resolvers  # noqa: E501
        """
        pass

    def test_check_domain_monitor(self):
        """Test case for check_domain_monitor

        Run a one-shot free domain monitor posture check  # noqa: E501
        """
        pass

    def test_check_email_audit(self):
        """Test case for check_email_audit

        Run a one-shot free email audit across links, images, HTML, and client support  # noqa: E501
        """
        pass

    def test_check_email_auth_stack(self):
        """Test case for check_email_auth_stack

        Run a one-shot combined SPF, DKIM, DMARC, BIMI, MX, MTA-STS, and TLS-RPT check  # noqa: E501
        """
        pass

    def test_check_email_blacklist(self):
        """Test case for check_email_blacklist

        Check whether a domain or IP appears on configured DNS blacklists  # noqa: E501
        """
        pass

    def test_check_email_features_client_support(self):
        """Test case for check_email_features_client_support

        Check email client support for email HTML and CSS features  # noqa: E501
        """
        pass

    def test_create_new_fake_email_address(self):
        """Test case for create_new_fake_email_address

        Create a new email address using the fake email domains  # noqa: E501
        """
        pass

    def test_delete_new_fake_email_address(self):
        """Test case for delete_new_fake_email_address

        Delete a fake email address using the fake email domains  # noqa: E501
        """
        pass

    def test_generate_bimi_record(self):
        """Test case for generate_bimi_record

        Create a BIMI record policy  # noqa: E501
        """
        pass

    def test_generate_dmarc_record(self):
        """Test case for generate_dmarc_record

        Create a DMARC record policy  # noqa: E501
        """
        pass

    def test_generate_mta_sts_record(self):
        """Test case for generate_mta_sts_record

        Create a TLS reporting record policy  # noqa: E501
        """
        pass

    def test_generate_spf_record(self):
        """Test case for generate_spf_record

        Create an SPF record  # noqa: E501
        """
        pass

    def test_generate_tls_reporting_record(self):
        """Test case for generate_tls_reporting_record

        Create a TLS reporting record policy  # noqa: E501
        """
        pass

    def test_get_fake_email_by_email_address(self):
        """Test case for get_fake_email_by_email_address

        """
        pass

    def test_get_fake_email_by_id(self):
        """Test case for get_fake_email_by_id

        Get a fake email by its ID  # noqa: E501
        """
        pass

    def test_get_fake_email_raw(self):
        """Test case for get_fake_email_raw

        Get raw fake email content  # noqa: E501
        """
        pass

    def test_get_fake_emails_for_address(self):
        """Test case for get_fake_emails_for_address

        Get fake emails for an address  # noqa: E501
        """
        pass

    def test_lookup_bimi_domain(self):
        """Test case for lookup_bimi_domain

        Lookup a BIMI record policy  # noqa: E501
        """
        pass

    def test_lookup_dkim_domain(self):
        """Test case for lookup_dkim_domain

        Lookup and validate a DKIM record  # noqa: E501
        """
        pass

    def test_lookup_dmarc_domain(self):
        """Test case for lookup_dmarc_domain

        Lookup a DMARC record policy  # noqa: E501
        """
        pass

    def test_lookup_mta_sts_domain(self):
        """Test case for lookup_mta_sts_domain

        Lookup a MTA-STS domain policy  # noqa: E501
        """
        pass

    def test_lookup_mx_record(self):
        """Test case for lookup_mx_record

        Lookup a MX records for a domain  # noqa: E501
        """
        pass

    def test_lookup_ptr(self):
        """Test case for lookup_ptr

        Lookup PTR records for an IP address  # noqa: E501
        """
        pass

    def test_lookup_spf_domain(self):
        """Test case for lookup_spf_domain

        Lookup and validate an SPF record  # noqa: E501
        """
        pass

    def test_lookup_tls_reporting_domain(self):
        """Test case for lookup_tls_reporting_domain

        Lookup a TLS reporting domain policy  # noqa: E501
        """
        pass

    def test_test_smtp_server(self):
        """Test case for test_smtp_server

        Run a conservative SMTP connectivity, TLS, and AUTH diagnostic  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class InboxReplierEventProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'message': 'str',
        'id': 'str',
        'status': 'str',
        'recipients': 'list[str]',
        'user_id': 'str',
        'email_id': 'str',
        'inbox_id': 'str',
        'created_at': 'datetime',
        'sent_id': 'str',
        'replier_id': 'str'
    }

    attribute_map = {
        'message': 'message',
        'id': 'id',
        'status': 'status',
        'recipients': 'recipients',
        'user_id': 'userId',
        'email_id': 'emailId',
        'inbox_id': 'inboxId',
        'created_at': 'createdAt',
        'sent_id': 'sentId',
        'replier_id': 'replierId'
    }

    def __init__(self, message=None, id=None, status=None, recipients=None, user_id=None, email_id=None, inbox_id=None, created_at=None, sent_id=None, replier_id=None, local_vars_configuration=None):  # noqa: E501
        """InboxReplierEventProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._message = None
        self._id = None
        self._status = None
        self._recipients = None
        self._user_id = None
        self._email_id = None
        self._inbox_id = None
        self._created_at = None
        self._sent_id = None
        self._replier_id = None
        self.discriminator = None

        self.message = message
        self.id = id
        self.status = status
        self.recipients = recipients
        self.user_id = user_id
        self.email_id = email_id
        self.inbox_id = inbox_id
        self.created_at = created_at
        self.sent_id = sent_id
        self.replier_id = replier_id

    @property
    def message(self):
        """Gets the message of this InboxReplierEventProjection.  # noqa: E501


        :return: The message of this InboxReplierEventProjection.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this InboxReplierEventProjection.


        :param message: The message of this InboxReplierEventProjection.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def id(self):
        """Gets the id of this InboxReplierEventProjection.  # noqa: E501


        :return: The id of this InboxReplierEventProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InboxReplierEventProjection.


        :param id: The id of this InboxReplierEventProjection.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def status(self):
        """Gets the status of this InboxReplierEventProjection.  # noqa: E501


        :return: The status of this InboxReplierEventProjection.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InboxReplierEventProjection.


        :param status: The status of this InboxReplierEventProjection.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"SUCCESS", "FAILURE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def recipients(self):
        """Gets the recipients of this InboxReplierEventProjection.  # noqa: E501


        :return: The recipients of this InboxReplierEventProjection.  # noqa: E501
        :rtype: list[str]
        """
        return self._recipients

    @recipients.setter
    def recipients(self, recipients):
        """Sets the recipients of this InboxReplierEventProjection.


        :param recipients: The recipients of this InboxReplierEventProjection.  # noqa: E501
        :type: list[str]
        """

        self._recipients = recipients

    @property
    def user_id(self):
        """Gets the user_id of this InboxReplierEventProjection.  # noqa: E501


        :return: The user_id of this InboxReplierEventProjection.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this InboxReplierEventProjection.


        :param user_id: The user_id of this InboxReplierEventProjection.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def email_id(self):
        """Gets the email_id of this InboxReplierEventProjection.  # noqa: E501


        :return: The email_id of this InboxReplierEventProjection.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this InboxReplierEventProjection.


        :param email_id: The email_id of this InboxReplierEventProjection.  # noqa: E501
        :type: str
        """

        self._email_id = email_id

    @property
    def inbox_id(self):
        """Gets the inbox_id of this InboxReplierEventProjection.  # noqa: E501


        :return: The inbox_id of this InboxReplierEventProjection.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this InboxReplierEventProjection.


        :param inbox_id: The inbox_id of this InboxReplierEventProjection.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def created_at(self):
        """Gets the created_at of this InboxReplierEventProjection.  # noqa: E501


        :return: The created_at of this InboxReplierEventProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InboxReplierEventProjection.


        :param created_at: The created_at of this InboxReplierEventProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def sent_id(self):
        """Gets the sent_id of this InboxReplierEventProjection.  # noqa: E501


        :return: The sent_id of this InboxReplierEventProjection.  # noqa: E501
        :rtype: str
        """
        return self._sent_id

    @sent_id.setter
    def sent_id(self, sent_id):
        """Sets the sent_id of this InboxReplierEventProjection.


        :param sent_id: The sent_id of this InboxReplierEventProjection.  # noqa: E501
        :type: str
        """

        self._sent_id = sent_id

    @property
    def replier_id(self):
        """Gets the replier_id of this InboxReplierEventProjection.  # noqa: E501


        :return: The replier_id of this InboxReplierEventProjection.  # noqa: E501
        :rtype: str
        """
        return self._replier_id

    @replier_id.setter
    def replier_id(self, replier_id):
        """Sets the replier_id of this InboxReplierEventProjection.


        :param replier_id: The replier_id of this InboxReplierEventProjection.  # noqa: E501
        :type: str
        """

        self._replier_id = replier_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InboxReplierEventProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InboxReplierEventProjection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DevicePreviewRunDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'run_id': 'str',
        'email_id': 'str',
        'status': 'str',
        'primary_screenshot_id': 'str',
        'requested_providers': 'list[str]',
        'imported_providers': 'list[str]',
        'warnings': 'list[str]',
        'provider_message_ids': 'dict(str, str)',
        'target_count': 'int',
        'screenshot_count': 'int',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'run_id': 'runId',
        'email_id': 'emailId',
        'status': 'status',
        'primary_screenshot_id': 'primaryScreenshotId',
        'requested_providers': 'requestedProviders',
        'imported_providers': 'importedProviders',
        'warnings': 'warnings',
        'provider_message_ids': 'providerMessageIds',
        'target_count': 'targetCount',
        'screenshot_count': 'screenshotCount',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, run_id=None, email_id=None, status=None, primary_screenshot_id=None, requested_providers=None, imported_providers=None, warnings=None, provider_message_ids=None, target_count=None, screenshot_count=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """DevicePreviewRunDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._run_id = None
        self._email_id = None
        self._status = None
        self._primary_screenshot_id = None
        self._requested_providers = None
        self._imported_providers = None
        self._warnings = None
        self._provider_message_ids = None
        self._target_count = None
        self._screenshot_count = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.run_id = run_id
        self.email_id = email_id
        self.status = status
        if primary_screenshot_id is not None:
            self.primary_screenshot_id = primary_screenshot_id
        if requested_providers is not None:
            self.requested_providers = requested_providers
        if imported_providers is not None:
            self.imported_providers = imported_providers
        if warnings is not None:
            self.warnings = warnings
        if provider_message_ids is not None:
            self.provider_message_ids = provider_message_ids
        self.target_count = target_count
        self.screenshot_count = screenshot_count
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def run_id(self):
        """Gets the run_id of this DevicePreviewRunDto.  # noqa: E501


        :return: The run_id of this DevicePreviewRunDto.  # noqa: E501
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this DevicePreviewRunDto.


        :param run_id: The run_id of this DevicePreviewRunDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and run_id is None:  # noqa: E501
            raise ValueError("Invalid value for `run_id`, must not be `None`")  # noqa: E501

        self._run_id = run_id

    @property
    def email_id(self):
        """Gets the email_id of this DevicePreviewRunDto.  # noqa: E501


        :return: The email_id of this DevicePreviewRunDto.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this DevicePreviewRunDto.


        :param email_id: The email_id of this DevicePreviewRunDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and email_id is None:  # noqa: E501
            raise ValueError("Invalid value for `email_id`, must not be `None`")  # noqa: E501

        self._email_id = email_id

    @property
    def status(self):
        """Gets the status of this DevicePreviewRunDto.  # noqa: E501


        :return: The status of this DevicePreviewRunDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DevicePreviewRunDto.


        :param status: The status of this DevicePreviewRunDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["CREATED", "AWAITING_ARRIVAL", "CAPTURING", "PARTIAL_COMPLETE", "COMPLETE", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def primary_screenshot_id(self):
        """Gets the primary_screenshot_id of this DevicePreviewRunDto.  # noqa: E501


        :return: The primary_screenshot_id of this DevicePreviewRunDto.  # noqa: E501
        :rtype: str
        """
        return self._primary_screenshot_id

    @primary_screenshot_id.setter
    def primary_screenshot_id(self, primary_screenshot_id):
        """Sets the primary_screenshot_id of this DevicePreviewRunDto.


        :param primary_screenshot_id: The primary_screenshot_id of this DevicePreviewRunDto.  # noqa: E501
        :type: str
        """

        self._primary_screenshot_id = primary_screenshot_id

    @property
    def requested_providers(self):
        """Gets the requested_providers of this DevicePreviewRunDto.  # noqa: E501


        :return: The requested_providers of this DevicePreviewRunDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._requested_providers

    @requested_providers.setter
    def requested_providers(self, requested_providers):
        """Sets the requested_providers of this DevicePreviewRunDto.


        :param requested_providers: The requested_providers of this DevicePreviewRunDto.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["GMAIL", "OUTLOOK", "YAHOO"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(requested_providers).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `requested_providers` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(requested_providers) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._requested_providers = requested_providers

    @property
    def imported_providers(self):
        """Gets the imported_providers of this DevicePreviewRunDto.  # noqa: E501


        :return: The imported_providers of this DevicePreviewRunDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._imported_providers

    @imported_providers.setter
    def imported_providers(self, imported_providers):
        """Sets the imported_providers of this DevicePreviewRunDto.


        :param imported_providers: The imported_providers of this DevicePreviewRunDto.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["GMAIL", "OUTLOOK", "YAHOO"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(imported_providers).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `imported_providers` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(imported_providers) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._imported_providers = imported_providers

    @property
    def warnings(self):
        """Gets the warnings of this DevicePreviewRunDto.  # noqa: E501


        :return: The warnings of this DevicePreviewRunDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this DevicePreviewRunDto.


        :param warnings: The warnings of this DevicePreviewRunDto.  # noqa: E501
        :type: list[str]
        """

        self._warnings = warnings

    @property
    def provider_message_ids(self):
        """Gets the provider_message_ids of this DevicePreviewRunDto.  # noqa: E501


        :return: The provider_message_ids of this DevicePreviewRunDto.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._provider_message_ids

    @provider_message_ids.setter
    def provider_message_ids(self, provider_message_ids):
        """Sets the provider_message_ids of this DevicePreviewRunDto.


        :param provider_message_ids: The provider_message_ids of this DevicePreviewRunDto.  # noqa: E501
        :type: dict(str, str)
        """

        self._provider_message_ids = provider_message_ids

    @property
    def target_count(self):
        """Gets the target_count of this DevicePreviewRunDto.  # noqa: E501


        :return: The target_count of this DevicePreviewRunDto.  # noqa: E501
        :rtype: int
        """
        return self._target_count

    @target_count.setter
    def target_count(self, target_count):
        """Sets the target_count of this DevicePreviewRunDto.


        :param target_count: The target_count of this DevicePreviewRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and target_count is None:  # noqa: E501
            raise ValueError("Invalid value for `target_count`, must not be `None`")  # noqa: E501

        self._target_count = target_count

    @property
    def screenshot_count(self):
        """Gets the screenshot_count of this DevicePreviewRunDto.  # noqa: E501


        :return: The screenshot_count of this DevicePreviewRunDto.  # noqa: E501
        :rtype: int
        """
        return self._screenshot_count

    @screenshot_count.setter
    def screenshot_count(self, screenshot_count):
        """Sets the screenshot_count of this DevicePreviewRunDto.


        :param screenshot_count: The screenshot_count of this DevicePreviewRunDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and screenshot_count is None:  # noqa: E501
            raise ValueError("Invalid value for `screenshot_count`, must not be `None`")  # noqa: E501

        self._screenshot_count = screenshot_count

    @property
    def created_at(self):
        """Gets the created_at of this DevicePreviewRunDto.  # noqa: E501


        :return: The created_at of this DevicePreviewRunDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DevicePreviewRunDto.


        :param created_at: The created_at of this DevicePreviewRunDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this DevicePreviewRunDto.  # noqa: E501


        :return: The updated_at of this DevicePreviewRunDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DevicePreviewRunDto.


        :param updated_at: The updated_at of this DevicePreviewRunDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicePreviewRunDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DevicePreviewRunDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilityExpectation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'min_count': 'int',
        '_from': 'str',
        'to': 'str',
        'subject': 'str'
    }

    attribute_map = {
        'name': 'name',
        'min_count': 'minCount',
        '_from': 'from',
        'to': 'to',
        'subject': 'subject'
    }

    def __init__(self, name=None, min_count=None, _from=None, to=None, subject=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilityExpectation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._min_count = None
        self.__from = None
        self._to = None
        self._subject = None
        self.discriminator = None

        self.name = name
        self.min_count = min_count
        self._from = _from
        self.to = to
        self.subject = subject

    @property
    def name(self):
        """Gets the name of this DeliverabilityExpectation.  # noqa: E501

        Optional label for this expectation  # noqa: E501

        :return: The name of this DeliverabilityExpectation.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DeliverabilityExpectation.

        Optional label for this expectation  # noqa: E501

        :param name: The name of this DeliverabilityExpectation.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def min_count(self):
        """Gets the min_count of this DeliverabilityExpectation.  # noqa: E501

        Minimum number of matching messages required for this expectation to pass  # noqa: E501

        :return: The min_count of this DeliverabilityExpectation.  # noqa: E501
        :rtype: int
        """
        return self._min_count

    @min_count.setter
    def min_count(self, min_count):
        """Sets the min_count of this DeliverabilityExpectation.

        Minimum number of matching messages required for this expectation to pass  # noqa: E501

        :param min_count: The min_count of this DeliverabilityExpectation.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and min_count is None:  # noqa: E501
            raise ValueError("Invalid value for `min_count`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                min_count is not None and min_count < 1):  # noqa: E501
            raise ValueError("Invalid value for `min_count`, must be a value greater than or equal to `1`")  # noqa: E501

        self._min_count = min_count

    @property
    def _from(self):
        """Gets the _from of this DeliverabilityExpectation.  # noqa: E501

        Optional sender filter. Matching is case-insensitive contains against inbound sender/from values.  # noqa: E501

        :return: The _from of this DeliverabilityExpectation.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this DeliverabilityExpectation.

        Optional sender filter. Matching is case-insensitive contains against inbound sender/from values.  # noqa: E501

        :param _from: The _from of this DeliverabilityExpectation.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this DeliverabilityExpectation.  # noqa: E501

        Optional recipient filter. Matching is case-insensitive contains against recipient/to values.  # noqa: E501

        :return: The to of this DeliverabilityExpectation.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this DeliverabilityExpectation.

        Optional recipient filter. Matching is case-insensitive contains against recipient/to values.  # noqa: E501

        :param to: The to of this DeliverabilityExpectation.  # noqa: E501
        :type: str
        """

        self._to = to

    @property
    def subject(self):
        """Gets the subject of this DeliverabilityExpectation.  # noqa: E501

        Optional subject filter for INBOX scope tests. Ignored for PHONE scope tests.  # noqa: E501

        :return: The subject of this DeliverabilityExpectation.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this DeliverabilityExpectation.

        Optional subject filter for INBOX scope tests. Ignored for PHONE scope tests.  # noqa: E501

        :param subject: The subject of this DeliverabilityExpectation.  # noqa: E501
        :type: str
        """

        self._subject = subject

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilityExpectation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilityExpectation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class FakeEmailDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'email_address': 'str',
        'sender': 'Sender',
        'recipients': 'EmailRecipients',
        'attachment_names': 'list[str]',
        'subject': 'str',
        'preview': 'str',
        'body': 'str',
        'seen': 'bool',
        'created_at': 'datetime',
        'content_type': 'str',
        'body_url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'email_address': 'emailAddress',
        'sender': 'sender',
        'recipients': 'recipients',
        'attachment_names': 'attachmentNames',
        'subject': 'subject',
        'preview': 'preview',
        'body': 'body',
        'seen': 'seen',
        'created_at': 'createdAt',
        'content_type': 'contentType',
        'body_url': 'bodyUrl'
    }

    def __init__(self, id=None, email_address=None, sender=None, recipients=None, attachment_names=None, subject=None, preview=None, body=None, seen=None, created_at=None, content_type=None, body_url=None, local_vars_configuration=None):  # noqa: E501
        """FakeEmailDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._email_address = None
        self._sender = None
        self._recipients = None
        self._attachment_names = None
        self._subject = None
        self._preview = None
        self._body = None
        self._seen = None
        self._created_at = None
        self._content_type = None
        self._body_url = None
        self.discriminator = None

        self.id = id
        self.email_address = email_address
        self.sender = sender
        self.recipients = recipients
        self.attachment_names = attachment_names
        if subject is not None:
            self.subject = subject
        if preview is not None:
            self.preview = preview
        self.body = body
        self.seen = seen
        self.created_at = created_at
        self.content_type = content_type
        self.body_url = body_url

    @property
    def id(self):
        """Gets the id of this FakeEmailDto.  # noqa: E501


        :return: The id of this FakeEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FakeEmailDto.


        :param id: The id of this FakeEmailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def email_address(self):
        """Gets the email_address of this FakeEmailDto.  # noqa: E501


        :return: The email_address of this FakeEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this FakeEmailDto.


        :param email_address: The email_address of this FakeEmailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and email_address is None:  # noqa: E501
            raise ValueError("Invalid value for `email_address`, must not be `None`")  # noqa: E501

        self._email_address = email_address

    @property
    def sender(self):
        """Gets the sender of this FakeEmailDto.  # noqa: E501


        :return: The sender of this FakeEmailDto.  # noqa: E501
        :rtype: Sender
        """
        return self._sender

    @sender.setter
    def sender(self, sender):
        """Sets the sender of this FakeEmailDto.


        :param sender: The sender of this FakeEmailDto.  # noqa: E501
        :type: Sender
        """

        self._sender = sender

    @property
    def recipients(self):
        """Gets the recipients of this FakeEmailDto.  # noqa: E501


        :return: The recipients of this FakeEmailDto.  # noqa: E501
        :rtype: EmailRecipients
        """
        return self._recipients

    @recipients.setter
    def recipients(self, recipients):
        """Sets the recipients of this FakeEmailDto.


        :param recipients: The recipients of this FakeEmailDto.  # noqa: E501
        :type: EmailRecipients
        """

        self._recipients = recipients

    @property
    def attachment_names(self):
        """Gets the attachment_names of this FakeEmailDto.  # noqa: E501


        :return: The attachment_names of this FakeEmailDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._attachment_names

    @attachment_names.setter
    def attachment_names(self, attachment_names):
        """Sets the attachment_names of this FakeEmailDto.


        :param attachment_names: The attachment_names of this FakeEmailDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and attachment_names is None:  # noqa: E501
            raise ValueError("Invalid value for `attachment_names`, must not be `None`")  # noqa: E501

        self._attachment_names = attachment_names

    @property
    def subject(self):
        """Gets the subject of this FakeEmailDto.  # noqa: E501


        :return: The subject of this FakeEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this FakeEmailDto.


        :param subject: The subject of this FakeEmailDto.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def preview(self):
        """Gets the preview of this FakeEmailDto.  # noqa: E501


        :return: The preview of this FakeEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._preview

    @preview.setter
    def preview(self, preview):
        """Sets the preview of this FakeEmailDto.


        :param preview: The preview of this FakeEmailDto.  # noqa: E501
        :type: str
        """

        self._preview = preview

    @property
    def body(self):
        """Gets the body of this FakeEmailDto.  # noqa: E501

        use read content endpoints instead  # noqa: E501

        :return: The body of this FakeEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this FakeEmailDto.

        use read content endpoints instead  # noqa: E501

        :param body: The body of this FakeEmailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and body is None:  # noqa: E501
            raise ValueError("Invalid value for `body`, must not be `None`")  # noqa: E501

        self._body = body

    @property
    def seen(self):
        """Gets the seen of this FakeEmailDto.  # noqa: E501


        :return: The seen of this FakeEmailDto.  # noqa: E501
        :rtype: bool
        """
        return self._seen

    @seen.setter
    def seen(self, seen):
        """Sets the seen of this FakeEmailDto.


        :param seen: The seen of this FakeEmailDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and seen is None:  # noqa: E501
            raise ValueError("Invalid value for `seen`, must not be `None`")  # noqa: E501

        self._seen = seen

    @property
    def created_at(self):
        """Gets the created_at of this FakeEmailDto.  # noqa: E501


        :return: The created_at of this FakeEmailDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this FakeEmailDto.


        :param created_at: The created_at of this FakeEmailDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def content_type(self):
        """Gets the content_type of this FakeEmailDto.  # noqa: E501


        :return: The content_type of this FakeEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this FakeEmailDto.


        :param content_type: The content_type of this FakeEmailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and content_type is None:  # noqa: E501
            raise ValueError("Invalid value for `content_type`, must not be `None`")  # noqa: E501

        self._content_type = content_type

    @property
    def body_url(self):
        """Gets the body_url of this FakeEmailDto.  # noqa: E501


        :return: The body_url of this FakeEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._body_url

    @body_url.setter
    def body_url(self, body_url):
        """Sets the body_url of this FakeEmailDto.


        :param body_url: The body_url of this FakeEmailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and body_url is None:  # noqa: E501
            raise ValueError("Invalid value for `body_url`, must not be `None`")  # noqa: E501

        self._body_url = body_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FakeEmailDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FakeEmailDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mailslurp_client.api_client import ApiClient
from mailslurp_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DomainMonitorControllerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def compare_domain_monitor_runs(self, monitor_id, run_id, other_run_id, **kwargs):  # noqa: E501
        """Compare two monitor runs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.compare_domain_monitor_runs(monitor_id, run_id, other_run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param str run_id: (required)
        :param str other_run_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainMonitorRunComparisonDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.compare_domain_monitor_runs_with_http_info(monitor_id, run_id, other_run_id, **kwargs)  # noqa: E501

    def compare_domain_monitor_runs_with_http_info(self, monitor_id, run_id, other_run_id, **kwargs):  # noqa: E501
        """Compare two monitor runs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.compare_domain_monitor_runs_with_http_info(monitor_id, run_id, other_run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param str run_id: (required)
        :param str other_run_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainMonitorRunComparisonDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'monitor_id',
            'run_id',
            'other_run_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method compare_domain_monitor_runs" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'monitor_id' is set
        if self.api_client.client_side_validation and ('monitor_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['monitor_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `monitor_id` when calling `compare_domain_monitor_runs`")  # noqa: E501
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['run_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `run_id` when calling `compare_domain_monitor_runs`")  # noqa: E501
        # verify the required parameter 'other_run_id' is set
        if self.api_client.client_side_validation and ('other_run_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['other_run_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `other_run_id` when calling `compare_domain_monitor_runs`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id' in local_var_params:
            path_params['monitorId'] = local_var_params['monitor_id']  # noqa: E501
        if 'run_id' in local_var_params:
            path_params['runId'] = local_var_params['run_id']  # noqa: E501
        if 'other_run_id' in local_var_params:
            path_params['otherRunId'] = local_var_params['other_run_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/{monitorId}/runs/{runId}/compare/{otherRunId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainMonitorRunComparisonDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_domain_monitor(self, create_domain_monitor_options, **kwargs):  # noqa: E501
        """Create domain monitor  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_domain_monitor(create_domain_monitor_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateDomainMonitorOptions create_domain_monitor_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainMonitorDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_domain_monitor_with_http_info(create_domain_monitor_options, **kwargs)  # noqa: E501

    def create_domain_monitor_with_http_info(self, create_domain_monitor_options, **kwargs):  # noqa: E501
        """Create domain monitor  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_domain_monitor_with_http_info(create_domain_monitor_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateDomainMonitorOptions create_domain_monitor_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainMonitorDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'create_domain_monitor_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_domain_monitor" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'create_domain_monitor_options' is set
        if self.api_client.client_side_validation and ('create_domain_monitor_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['create_domain_monitor_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `create_domain_monitor_options` when calling `create_domain_monitor`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_domain_monitor_options' in local_var_params:
            body_params = local_var_params['create_domain_monitor_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainMonitorDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_domain_monitor_alert_sink(self, monitor_id, create_domain_monitor_alert_sink_options, **kwargs):  # noqa: E501
        """Create alert sink for monitor  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_domain_monitor_alert_sink(monitor_id, create_domain_monitor_alert_sink_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param CreateDomainMonitorAlertSinkOptions create_domain_monitor_alert_sink_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainMonitorAlertSinkDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_domain_monitor_alert_sink_with_http_info(monitor_id, create_domain_monitor_alert_sink_options, **kwargs)  # noqa: E501

    def create_domain_monitor_alert_sink_with_http_info(self, monitor_id, create_domain_monitor_alert_sink_options, **kwargs):  # noqa: E501
        """Create alert sink for monitor  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_domain_monitor_alert_sink_with_http_info(monitor_id, create_domain_monitor_alert_sink_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param CreateDomainMonitorAlertSinkOptions create_domain_monitor_alert_sink_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainMonitorAlertSinkDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'monitor_id',
            'create_domain_monitor_alert_sink_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_domain_monitor_alert_sink" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'monitor_id' is set
        if self.api_client.client_side_validation and ('monitor_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['monitor_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `monitor_id` when calling `create_domain_monitor_alert_sink`")  # noqa: E501
        # verify the required parameter 'create_domain_monitor_alert_sink_options' is set
        if self.api_client.client_side_validation and ('create_domain_monitor_alert_sink_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['create_domain_monitor_alert_sink_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `create_domain_monitor_alert_sink_options` when calling `create_domain_monitor_alert_sink`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id' in local_var_params:
            path_params['monitorId'] = local_var_params['monitor_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_domain_monitor_alert_sink_options' in local_var_params:
            body_params = local_var_params['create_domain_monitor_alert_sink_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/{monitorId}/alert-sinks', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainMonitorAlertSinkDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_domain_monitor(self, monitor_id, **kwargs):  # noqa: E501
        """Delete domain monitor  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_domain_monitor(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_domain_monitor_with_http_info(monitor_id, **kwargs)  # noqa: E501

    def delete_domain_monitor_with_http_info(self, monitor_id, **kwargs):  # noqa: E501
        """Delete domain monitor  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_domain_monitor_with_http_info(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'monitor_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_domain_monitor" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'monitor_id' is set
        if self.api_client.client_side_validation and ('monitor_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['monitor_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `monitor_id` when calling `delete_domain_monitor`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id' in local_var_params:
            path_params['monitorId'] = local_var_params['monitor_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/{monitorId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_domain_monitor_alert_sink(self, monitor_id, sink_id, **kwargs):  # noqa: E501
        """Delete monitor alert sink  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_domain_monitor_alert_sink(monitor_id, sink_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param str sink_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_domain_monitor_alert_sink_with_http_info(monitor_id, sink_id, **kwargs)  # noqa: E501

    def delete_domain_monitor_alert_sink_with_http_info(self, monitor_id, sink_id, **kwargs):  # noqa: E501
        """Delete monitor alert sink  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_domain_monitor_alert_sink_with_http_info(monitor_id, sink_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param str sink_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'monitor_id',
            'sink_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_domain_monitor_alert_sink" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'monitor_id' is set
        if self.api_client.client_side_validation and ('monitor_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['monitor_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `monitor_id` when calling `delete_domain_monitor_alert_sink`")  # noqa: E501
        # verify the required parameter 'sink_id' is set
        if self.api_client.client_side_validation and ('sink_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['sink_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sink_id` when calling `delete_domain_monitor_alert_sink`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id' in local_var_params:
            path_params['monitorId'] = local_var_params['monitor_id']  # noqa: E501
        if 'sink_id' in local_var_params:
            path_params['sinkId'] = local_var_params['sink_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/{monitorId}/alert-sinks/{sinkId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_domain_monitor(self, monitor_id, **kwargs):  # noqa: E501
        """Get domain monitor  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainMonitorDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_domain_monitor_with_http_info(monitor_id, **kwargs)  # noqa: E501

    def get_domain_monitor_with_http_info(self, monitor_id, **kwargs):  # noqa: E501
        """Get domain monitor  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_with_http_info(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainMonitorDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'monitor_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_domain_monitor" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'monitor_id' is set
        if self.api_client.client_side_validation and ('monitor_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['monitor_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `monitor_id` when calling `get_domain_monitor`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id' in local_var_params:
            path_params['monitorId'] = local_var_params['monitor_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/{monitorId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainMonitorDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_domain_monitor_alert_sinks(self, monitor_id, **kwargs):  # noqa: E501
        """List alert sinks for monitor  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_alert_sinks(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DomainMonitorAlertSinkDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_domain_monitor_alert_sinks_with_http_info(monitor_id, **kwargs)  # noqa: E501

    def get_domain_monitor_alert_sinks_with_http_info(self, monitor_id, **kwargs):  # noqa: E501
        """List alert sinks for monitor  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_alert_sinks_with_http_info(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DomainMonitorAlertSinkDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'monitor_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_domain_monitor_alert_sinks" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'monitor_id' is set
        if self.api_client.client_side_validation and ('monitor_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['monitor_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `monitor_id` when calling `get_domain_monitor_alert_sinks`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id' in local_var_params:
            path_params['monitorId'] = local_var_params['monitor_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/{monitorId}/alert-sinks', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DomainMonitorAlertSinkDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_domain_monitor_auth_stack(self, monitor_id, **kwargs):  # noqa: E501
        """Get current auth stack for monitor domain  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_auth_stack(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param str dkim_selector:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CheckEmailAuthStackResults
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_domain_monitor_auth_stack_with_http_info(monitor_id, **kwargs)  # noqa: E501

    def get_domain_monitor_auth_stack_with_http_info(self, monitor_id, **kwargs):  # noqa: E501
        """Get current auth stack for monitor domain  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_auth_stack_with_http_info(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param str dkim_selector:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CheckEmailAuthStackResults, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'monitor_id',
            'dkim_selector'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_domain_monitor_auth_stack" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'monitor_id' is set
        if self.api_client.client_side_validation and ('monitor_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['monitor_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `monitor_id` when calling `get_domain_monitor_auth_stack`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id' in local_var_params:
            path_params['monitorId'] = local_var_params['monitor_id']  # noqa: E501

        query_params = []
        if 'dkim_selector' in local_var_params and local_var_params['dkim_selector'] is not None:  # noqa: E501
            query_params.append(('dkimSelector', local_var_params['dkim_selector']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/{monitorId}/auth-stack', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CheckEmailAuthStackResults',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_domain_monitor_insights(self, monitor_id, **kwargs):  # noqa: E501
        """Get monitor insights  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_insights(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param datetime since:
        :param datetime before:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainMonitorInsightsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_domain_monitor_insights_with_http_info(monitor_id, **kwargs)  # noqa: E501

    def get_domain_monitor_insights_with_http_info(self, monitor_id, **kwargs):  # noqa: E501
        """Get monitor insights  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_insights_with_http_info(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param datetime since:
        :param datetime before:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainMonitorInsightsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'monitor_id',
            'since',
            'before'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_domain_monitor_insights" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'monitor_id' is set
        if self.api_client.client_side_validation and ('monitor_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['monitor_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `monitor_id` when calling `get_domain_monitor_insights`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id' in local_var_params:
            path_params['monitorId'] = local_var_params['monitor_id']  # noqa: E501

        query_params = []
        if 'since' in local_var_params and local_var_params['since'] is not None:  # noqa: E501
            query_params.append(('since', local_var_params['since']))  # noqa: E501
        if 'before' in local_var_params and local_var_params['before'] is not None:  # noqa: E501
            query_params.append(('before', local_var_params['before']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/{monitorId}/insights', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainMonitorInsightsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_domain_monitor_run(self, monitor_id, run_id, **kwargs):  # noqa: E501
        """Get monitor run  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_run(monitor_id, run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param str run_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainMonitorRunDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_domain_monitor_run_with_http_info(monitor_id, run_id, **kwargs)  # noqa: E501

    def get_domain_monitor_run_with_http_info(self, monitor_id, run_id, **kwargs):  # noqa: E501
        """Get monitor run  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_run_with_http_info(monitor_id, run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param str run_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainMonitorRunDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'monitor_id',
            'run_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_domain_monitor_run" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'monitor_id' is set
        if self.api_client.client_side_validation and ('monitor_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['monitor_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `monitor_id` when calling `get_domain_monitor_run`")  # noqa: E501
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['run_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `run_id` when calling `get_domain_monitor_run`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id' in local_var_params:
            path_params['monitorId'] = local_var_params['monitor_id']  # noqa: E501
        if 'run_id' in local_var_params:
            path_params['runId'] = local_var_params['run_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/{monitorId}/runs/{runId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainMonitorRunDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_domain_monitor_runs(self, monitor_id, **kwargs):  # noqa: E501
        """List monitor runs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_runs(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param datetime since:
        :param datetime before:
        :param str status:
        :param int limit:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DomainMonitorRunDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_domain_monitor_runs_with_http_info(monitor_id, **kwargs)  # noqa: E501

    def get_domain_monitor_runs_with_http_info(self, monitor_id, **kwargs):  # noqa: E501
        """List monitor runs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_runs_with_http_info(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param datetime since:
        :param datetime before:
        :param str status:
        :param int limit:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DomainMonitorRunDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'monitor_id',
            'since',
            'before',
            'status',
            'limit'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_domain_monitor_runs" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'monitor_id' is set
        if self.api_client.client_side_validation and ('monitor_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['monitor_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `monitor_id` when calling `get_domain_monitor_runs`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id' in local_var_params:
            path_params['monitorId'] = local_var_params['monitor_id']  # noqa: E501

        query_params = []
        if 'since' in local_var_params and local_var_params['since'] is not None:  # noqa: E501
            query_params.append(('since', local_var_params['since']))  # noqa: E501
        if 'before' in local_var_params and local_var_params['before'] is not None:  # noqa: E501
            query_params.append(('before', local_var_params['before']))  # noqa: E501
        if 'status' in local_var_params and local_var_params['status'] is not None:  # noqa: E501
            query_params.append(('status', local_var_params['status']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/{monitorId}/runs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DomainMonitorRunDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_domain_monitor_series(self, monitor_id, **kwargs):  # noqa: E501
        """Get monitor trend series  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_series(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param datetime since:
        :param datetime before:
        :param str bucket:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainMonitorSeriesDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_domain_monitor_series_with_http_info(monitor_id, **kwargs)  # noqa: E501

    def get_domain_monitor_series_with_http_info(self, monitor_id, **kwargs):  # noqa: E501
        """Get monitor trend series  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_series_with_http_info(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param datetime since:
        :param datetime before:
        :param str bucket:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainMonitorSeriesDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'monitor_id',
            'since',
            'before',
            'bucket'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_domain_monitor_series" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'monitor_id' is set
        if self.api_client.client_side_validation and ('monitor_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['monitor_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `monitor_id` when calling `get_domain_monitor_series`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id' in local_var_params:
            path_params['monitorId'] = local_var_params['monitor_id']  # noqa: E501

        query_params = []
        if 'since' in local_var_params and local_var_params['since'] is not None:  # noqa: E501
            query_params.append(('since', local_var_params['since']))  # noqa: E501
        if 'before' in local_var_params and local_var_params['before'] is not None:  # noqa: E501
            query_params.append(('before', local_var_params['before']))  # noqa: E501
        if 'bucket' in local_var_params and local_var_params['bucket'] is not None:  # noqa: E501
            query_params.append(('bucket', local_var_params['bucket']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/{monitorId}/series', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainMonitorSeriesDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_domain_monitor_summary(self, monitor_id, **kwargs):  # noqa: E501
        """Get domain monitor summary  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_summary(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param str dkim_selector:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainMonitorSummaryDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_domain_monitor_summary_with_http_info(monitor_id, **kwargs)  # noqa: E501

    def get_domain_monitor_summary_with_http_info(self, monitor_id, **kwargs):  # noqa: E501
        """Get domain monitor summary  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitor_summary_with_http_info(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param str dkim_selector:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainMonitorSummaryDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'monitor_id',
            'dkim_selector'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_domain_monitor_summary" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'monitor_id' is set
        if self.api_client.client_side_validation and ('monitor_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['monitor_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `monitor_id` when calling `get_domain_monitor_summary`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id' in local_var_params:
            path_params['monitorId'] = local_var_params['monitor_id']  # noqa: E501

        query_params = []
        if 'dkim_selector' in local_var_params and local_var_params['dkim_selector'] is not None:  # noqa: E501
            query_params.append(('dkimSelector', local_var_params['dkim_selector']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/{monitorId}/summary', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainMonitorSummaryDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_domain_monitors(self, **kwargs):  # noqa: E501
        """List domain monitors  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitors(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DomainMonitorDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_domain_monitors_with_http_info(**kwargs)  # noqa: E501

    def get_domain_monitors_with_http_info(self, **kwargs):  # noqa: E501
        """List domain monitors  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_monitors_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DomainMonitorDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_domain_monitors" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DomainMonitorDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def run_domain_monitor_now(self, monitor_id, **kwargs):  # noqa: E501
        """Run monitor now  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.run_domain_monitor_now(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainMonitorRunNowResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.run_domain_monitor_now_with_http_info(monitor_id, **kwargs)  # noqa: E501

    def run_domain_monitor_now_with_http_info(self, monitor_id, **kwargs):  # noqa: E501
        """Run monitor now  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.run_domain_monitor_now_with_http_info(monitor_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainMonitorRunNowResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'monitor_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_domain_monitor_now" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'monitor_id' is set
        if self.api_client.client_side_validation and ('monitor_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['monitor_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `monitor_id` when calling `run_domain_monitor_now`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id' in local_var_params:
            path_params['monitorId'] = local_var_params['monitor_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/{monitorId}/run-now', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainMonitorRunNowResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def run_due_domain_monitors(self, **kwargs):  # noqa: E501
        """Run due monitors for user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.run_due_domain_monitors(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int max_runs:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainMonitorRunDueResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.run_due_domain_monitors_with_http_info(**kwargs)  # noqa: E501

    def run_due_domain_monitors_with_http_info(self, **kwargs):  # noqa: E501
        """Run due monitors for user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.run_due_domain_monitors_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int max_runs:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainMonitorRunDueResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'max_runs'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_due_domain_monitors" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'max_runs' in local_var_params and local_var_params['max_runs'] is not None:  # noqa: E501
            query_params.append(('maxRuns', local_var_params['max_runs']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/run-due', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainMonitorRunDueResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_domain_monitor(self, monitor_id, update_domain_monitor_options, **kwargs):  # noqa: E501
        """Update domain monitor  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_domain_monitor(monitor_id, update_domain_monitor_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param UpdateDomainMonitorOptions update_domain_monitor_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainMonitorDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_domain_monitor_with_http_info(monitor_id, update_domain_monitor_options, **kwargs)  # noqa: E501

    def update_domain_monitor_with_http_info(self, monitor_id, update_domain_monitor_options, **kwargs):  # noqa: E501
        """Update domain monitor  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_domain_monitor_with_http_info(monitor_id, update_domain_monitor_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str monitor_id: (required)
        :param UpdateDomainMonitorOptions update_domain_monitor_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainMonitorDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'monitor_id',
            'update_domain_monitor_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_domain_monitor" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'monitor_id' is set
        if self.api_client.client_side_validation and ('monitor_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['monitor_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `monitor_id` when calling `update_domain_monitor`")  # noqa: E501
        # verify the required parameter 'update_domain_monitor_options' is set
        if self.api_client.client_side_validation and ('update_domain_monitor_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_domain_monitor_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_domain_monitor_options` when calling `update_domain_monitor`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitor_id' in local_var_params:
            path_params['monitorId'] = local_var_params['monitor_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_domain_monitor_options' in local_var_params:
            body_params = local_var_params['update_domain_monitor_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/domain-monitor/monitors/{monitorId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainMonitorDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class GenerateSpfRecordOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'domain': 'str',
        'include_domains': 'list[str]',
        'ip4': 'list[str]',
        'ip6': 'list[str]',
        'mx': 'bool',
        'a': 'bool',
        'all_policy': 'str'
    }

    attribute_map = {
        'domain': 'domain',
        'include_domains': 'includeDomains',
        'ip4': 'ip4',
        'ip6': 'ip6',
        'mx': 'mx',
        'a': 'a',
        'all_policy': 'allPolicy'
    }

    def __init__(self, domain=None, include_domains=None, ip4=None, ip6=None, mx=None, a=None, all_policy=None, local_vars_configuration=None):  # noqa: E501
        """GenerateSpfRecordOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._domain = None
        self._include_domains = None
        self._ip4 = None
        self._ip6 = None
        self._mx = None
        self._a = None
        self._all_policy = None
        self.discriminator = None

        self.domain = domain
        self.include_domains = include_domains
        self.ip4 = ip4
        self.ip6 = ip6
        self.mx = mx
        self.a = a
        self.all_policy = all_policy

    @property
    def domain(self):
        """Gets the domain of this GenerateSpfRecordOptions.  # noqa: E501

        Domain the SPF record applies to  # noqa: E501

        :return: The domain of this GenerateSpfRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this GenerateSpfRecordOptions.

        Domain the SPF record applies to  # noqa: E501

        :param domain: The domain of this GenerateSpfRecordOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain is None:  # noqa: E501
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                domain is not None and len(domain) > 253):
            raise ValueError("Invalid value for `domain`, length must be less than or equal to `253`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                domain is not None and len(domain) < 0):
            raise ValueError("Invalid value for `domain`, length must be greater than or equal to `0`")  # noqa: E501

        self._domain = domain

    @property
    def include_domains(self):
        """Gets the include_domains of this GenerateSpfRecordOptions.  # noqa: E501

        Optional include domains  # noqa: E501

        :return: The include_domains of this GenerateSpfRecordOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._include_domains

    @include_domains.setter
    def include_domains(self, include_domains):
        """Sets the include_domains of this GenerateSpfRecordOptions.

        Optional include domains  # noqa: E501

        :param include_domains: The include_domains of this GenerateSpfRecordOptions.  # noqa: E501
        :type: list[str]
        """

        self._include_domains = include_domains

    @property
    def ip4(self):
        """Gets the ip4 of this GenerateSpfRecordOptions.  # noqa: E501

        Optional IPv4 CIDRs or hosts  # noqa: E501

        :return: The ip4 of this GenerateSpfRecordOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._ip4

    @ip4.setter
    def ip4(self, ip4):
        """Sets the ip4 of this GenerateSpfRecordOptions.

        Optional IPv4 CIDRs or hosts  # noqa: E501

        :param ip4: The ip4 of this GenerateSpfRecordOptions.  # noqa: E501
        :type: list[str]
        """

        self._ip4 = ip4

    @property
    def ip6(self):
        """Gets the ip6 of this GenerateSpfRecordOptions.  # noqa: E501

        Optional IPv6 CIDRs or hosts  # noqa: E501

        :return: The ip6 of this GenerateSpfRecordOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._ip6

    @ip6.setter
    def ip6(self, ip6):
        """Sets the ip6 of this GenerateSpfRecordOptions.

        Optional IPv6 CIDRs or hosts  # noqa: E501

        :param ip6: The ip6 of this GenerateSpfRecordOptions.  # noqa: E501
        :type: list[str]
        """

        self._ip6 = ip6

    @property
    def mx(self):
        """Gets the mx of this GenerateSpfRecordOptions.  # noqa: E501

        Whether to include the MX mechanism  # noqa: E501

        :return: The mx of this GenerateSpfRecordOptions.  # noqa: E501
        :rtype: bool
        """
        return self._mx

    @mx.setter
    def mx(self, mx):
        """Sets the mx of this GenerateSpfRecordOptions.

        Whether to include the MX mechanism  # noqa: E501

        :param mx: The mx of this GenerateSpfRecordOptions.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and mx is None:  # noqa: E501
            raise ValueError("Invalid value for `mx`, must not be `None`")  # noqa: E501

        self._mx = mx

    @property
    def a(self):
        """Gets the a of this GenerateSpfRecordOptions.  # noqa: E501

        Whether to include the A mechanism  # noqa: E501

        :return: The a of this GenerateSpfRecordOptions.  # noqa: E501
        :rtype: bool
        """
        return self._a

    @a.setter
    def a(self, a):
        """Sets the a of this GenerateSpfRecordOptions.

        Whether to include the A mechanism  # noqa: E501

        :param a: The a of this GenerateSpfRecordOptions.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and a is None:  # noqa: E501
            raise ValueError("Invalid value for `a`, must not be `None`")  # noqa: E501

        self._a = a

    @property
    def all_policy(self):
        """Gets the all_policy of this GenerateSpfRecordOptions.  # noqa: E501


        :return: The all_policy of this GenerateSpfRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._all_policy

    @all_policy.setter
    def all_policy(self, all_policy):
        """Sets the all_policy of this GenerateSpfRecordOptions.


        :param all_policy: The all_policy of this GenerateSpfRecordOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and all_policy is None:  # noqa: E501
            raise ValueError("Invalid value for `all_policy`, must not be `None`")  # noqa: E501
        allowed_values = ["FAIL", "SOFTFAIL", "NEUTRAL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and all_policy not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `all_policy` ({0}), must be one of {1}"  # noqa: E501
                .format(all_policy, allowed_values)
            )

        self._all_policy = all_policy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerateSpfRecordOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GenerateSpfRecordOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilitySelectorOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'pattern': 'str',
        'phone_country': 'str',
        'entity_ids': 'list[str]',
        'exclude_entity_ids': 'list[str]'
    }

    attribute_map = {
        'type': 'type',
        'pattern': 'pattern',
        'phone_country': 'phoneCountry',
        'entity_ids': 'entityIds',
        'exclude_entity_ids': 'excludeEntityIds'
    }

    def __init__(self, type=None, pattern=None, phone_country=None, entity_ids=None, exclude_entity_ids=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilitySelectorOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._pattern = None
        self._phone_country = None
        self._entity_ids = None
        self._exclude_entity_ids = None
        self.discriminator = None

        self.type = type
        self.pattern = pattern
        self.phone_country = phone_country
        self.entity_ids = entity_ids
        self.exclude_entity_ids = exclude_entity_ids

    @property
    def type(self):
        """Gets the type of this DeliverabilitySelectorOptions.  # noqa: E501

        Selection mode  # noqa: E501

        :return: The type of this DeliverabilitySelectorOptions.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DeliverabilitySelectorOptions.

        Selection mode  # noqa: E501

        :param type: The type of this DeliverabilitySelectorOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["ALL", "PATTERN", "EXPLICIT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def pattern(self):
        """Gets the pattern of this DeliverabilitySelectorOptions.  # noqa: E501

        Wildcard pattern for PATTERN selection. Supports '*' and '?' wildcards. If no wildcard is present the value is treated as a case-insensitive contains match.  # noqa: E501

        :return: The pattern of this DeliverabilitySelectorOptions.  # noqa: E501
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """Sets the pattern of this DeliverabilitySelectorOptions.

        Wildcard pattern for PATTERN selection. Supports '*' and '?' wildcards. If no wildcard is present the value is treated as a case-insensitive contains match.  # noqa: E501

        :param pattern: The pattern of this DeliverabilitySelectorOptions.  # noqa: E501
        :type: str
        """

        self._pattern = pattern

    @property
    def phone_country(self):
        """Gets the phone_country of this DeliverabilitySelectorOptions.  # noqa: E501

        Optional phone-country filter for PHONE scope selection (e.g. ALL phones in US). Must be null for INBOX scope.  # noqa: E501

        :return: The phone_country of this DeliverabilitySelectorOptions.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this DeliverabilitySelectorOptions.

        Optional phone-country filter for PHONE scope selection (e.g. ALL phones in US). Must be null for INBOX scope.  # noqa: E501

        :param phone_country: The phone_country of this DeliverabilitySelectorOptions.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def entity_ids(self):
        """Gets the entity_ids of this DeliverabilitySelectorOptions.  # noqa: E501

        Explicit entity IDs for EXPLICIT selection  # noqa: E501

        :return: The entity_ids of this DeliverabilitySelectorOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._entity_ids

    @entity_ids.setter
    def entity_ids(self, entity_ids):
        """Sets the entity_ids of this DeliverabilitySelectorOptions.

        Explicit entity IDs for EXPLICIT selection  # noqa: E501

        :param entity_ids: The entity_ids of this DeliverabilitySelectorOptions.  # noqa: E501
        :type: list[str]
        """

        self._entity_ids = entity_ids

    @property
    def exclude_entity_ids(self):
        """Gets the exclude_entity_ids of this DeliverabilitySelectorOptions.  # noqa: E501

        Optional entity IDs to exclude from the resolved selection (applies after ALL/PATTERN/EXPLICIT selection).  # noqa: E501

        :return: The exclude_entity_ids of this DeliverabilitySelectorOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._exclude_entity_ids

    @exclude_entity_ids.setter
    def exclude_entity_ids(self, exclude_entity_ids):
        """Sets the exclude_entity_ids of this DeliverabilitySelectorOptions.

        Optional entity IDs to exclude from the resolved selection (applies after ALL/PATTERN/EXPLICIT selection).  # noqa: E501

        :param exclude_entity_ids: The exclude_entity_ids of this DeliverabilitySelectorOptions.  # noqa: E501
        :type: list[str]
        """

        self._exclude_entity_ids = exclude_entity_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilitySelectorOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilitySelectorOptions):
            return True

        return self.to_dict() != other.to_dict()
